@@ -1,8 +1,7 @@
 #' Create a video from images and text
 #' 
 #' Given equal length vectors of paths to images (preferably \code{.jpg}s
-#' or \code{.png}s) and strings which will be
-#' \code{\link[aws.polly]{synthesize}}d by
+#' or \code{.png}s) and strings which will be synthesized by
 #' \href{https://aws.amazon.com/polly/}{Amazon Polly} or 
 #' any other synthesizer available in
 #' \code{\link[text2speech]{tts}}, this function creates an
@@ -15,7 +14,7 @@
 #' narration. You can find a guide for accessing AWS from R
 #' \href{http://seankross.com/2017/05/02/Access-Amazon-Web-Services-in-R.html}{here}.
 #' For more information about how R connects
-#' to Amazon Polly see the \code{\link[aws.polly]{aws.polly}} documentation 
+#' to Amazon Polly see the \code{aws.polly]} documentation 
 #' \href{https://github.com/cloudyr/aws.polly}{here}.
 #' 
 #' @param images A vector of paths to images.
@@ -25,7 +24,8 @@
 #' \code{\link[text2speech]{tts_voices}} for more information 
 #' about what voices are available.
 #' @param service speech synthesis service to use,
-#' passed to \code{\link[text2speech]{tts}}
+#' passed to \code{\link[text2speech]{tts}}.
+#' Either \code{"amazon"} or \code{"google"}.
 #' @param subtitles Should a \code{.srt} file be created with subtitles? The
 #' default value is \code{FALSE}. If \code{TRUE} then a file with the same name
 #' as the \code{output} argument will be created, but with the file extension
@@ -55,7 +55,7 @@ ari_spin <- function(
   images, paragraphs, 
   output = tempfile(fileext = ".mp4"),
   voice = text2speech::tts_default_voice(service = service),
-  service = ifelse(have_polly(), "amazon", "google"),
+  service = "amazon",
   subtitles = FALSE,
   ...){
   # check for ffmpeg before any synthesizing
@@ -136,9 +136,3 @@ ari_spin <- function(
   attr(res, "service") = service
   return(res)
 }
-
-#' @rdname ari_spin 
-#' @export
-have_polly = function() {
-  requireNamespace("aws.polly", quietly = TRUE)
-}
\ No newline at end of file
